@@ -51,7 +51,9 @@ class HTableModel(QAbstractTableModel):
     def removeRow(self, row: int, parent: QModelIndex = ...) -> bool:  # pylint: disable=unused-argument
         """TODO"""
         if 0 <= row < len(self.table_data):
+            self.beginRemoveRows(QModelIndex(), row, row)
             del self.table_data[row]
+            self.endRemoveRows()
             self.layoutChanged.emit()
             return True
         return False
